==> flink-1.19.2-src.tgz: flink-1.19.2/flink-runtime/src/main/java/org/apache/flink/runtime/state/memory/PersistentMetadataCheckpointStorageLocation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.state.memory;

import org.apache.flink.core.fs.FileSystem;
import org.apache.flink.core.fs.Path;
import org.apache.flink.runtime.state.CheckpointMetadataOutputStream;
import org.apache.flink.runtime.state.CheckpointStorageLocation;
import org.apache.flink.runtime.state.CheckpointStorageLocationReference;
import org.apache.flink.runtime.state.filesystem.AbstractFsCheckpointStorageAccess;
import org.apache.flink.runtime.state.filesystem.FsCheckpointMetadataOutputStream;

import java.io.IOException;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A checkpoint storage location for the {@link MemoryStateBackend} when it durably persists the
 * metadata in a file system.
 */
public class PersistentMetadataCheckpointStorageLocation extends MemCheckpointStreamFactory
        implements CheckpointStorageLocation {

    private final FileSystem fileSystem;

    private final Path checkpointDirectory;

    private final Path metadataFilePath;

    /**
     * Creates a checkpoint storage persists metadata to a file system and stores state in line in
     * state handles with the metadata.
     *
     * @param fileSystem The file system to which the metadata will be written.
     * @param checkpointDir The directory where the checkpoint metadata will be written.
     */
    public PersistentMetadataCheckpointStorageLocation(
            FileSystem fileSystem, Path checkpointDir, int maxStateSize) {

        super(maxStateSize);

        this.fileSystem = checkNotNull(fileSystem);
        this.checkpointDirectory = checkNotNull(checkpointDir);
        this.metadataFilePath =
                new Path(checkpointDir, AbstractFsCheckpointStorageAccess.METADATA_FILE_NAME);
    }

    // ------------------------------------------------------------------------

    @Override
    public CheckpointMetadataOutputStream createMetadataOutputStream() throws IOException {
        return new FsCheckpointMetadataOutputStream(
                fileSystem, metadataFilePath, checkpointDirectory);
    }

    @Override
    public void disposeOnFailure() throws IOException {
        // on a failure, no chunk in the checkpoint directory needs to be saved, so
        // we can drop it as a whole
        fileSystem.delete(checkpointDirectory, true);
    }

    @Override
    public CheckpointStorageLocationReference getLocationReference() {
        return CheckpointStorageLocationReference.getDefault();
    }
}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-runtime/src/main/java/org/apache/flink/runtime/state/memory/PersistentMetadataCheckpointStorageLocation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.state.memory;

import org.apache.flink.core.fs.FileSystem;
import org.apache.flink.core.fs.Path;
import org.apache.flink.runtime.state.CheckpointMetadataOutputStream;
import org.apache.flink.runtime.state.CheckpointStorageLocation;
import org.apache.flink.runtime.state.CheckpointStorageLocationReference;
import org.apache.flink.runtime.state.filesystem.AbstractFsCheckpointStorageAccess;
import org.apache.flink.runtime.state.filesystem.FsCheckpointMetadataOutputStream;

import java.io.IOException;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A checkpoint storage location for the {@link MemCheckpointStreamFactory} when it durably persists
 * the metadata in a file system.
 */
public class PersistentMetadataCheckpointStorageLocation extends MemCheckpointStreamFactory
        implements CheckpointStorageLocation {

    private final FileSystem fileSystem;

    private final Path checkpointDirectory;

    private final Path metadataFilePath;

    /**
     * Creates a checkpoint storage persists metadata to a file system and stores state in line in
     * state handles with the metadata.
     *
     * @param fileSystem The file system to which the metadata will be written.
     * @param checkpointDir The directory where the checkpoint metadata will be written.
     */
    public PersistentMetadataCheckpointStorageLocation(
            FileSystem fileSystem, Path checkpointDir, int maxStateSize) {

        super(maxStateSize);

        this.fileSystem = checkNotNull(fileSystem);
        this.checkpointDirectory = checkNotNull(checkpointDir);
        this.metadataFilePath =
                new Path(checkpointDir, AbstractFsCheckpointStorageAccess.METADATA_FILE_NAME);
    }

    // ------------------------------------------------------------------------

    @Override
    public CheckpointMetadataOutputStream createMetadataOutputStream() throws IOException {
        return new FsCheckpointMetadataOutputStream(
                fileSystem, metadataFilePath, checkpointDirectory);
    }

    @Override
    public void disposeOnFailure() throws IOException {
        // on a failure, no chunk in the checkpoint directory needs to be saved, so
        // we can drop it as a whole
        fileSystem.delete(checkpointDirectory, true);
    }

    @Override
    public CheckpointStorageLocationReference getLocationReference() {
        return CheckpointStorageLocationReference.getDefault();
    }
}
